@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2017  Ruby-GNOME2 Project Team
+# Copyright (C) 2012-2018  Ruby-GNOME2 Project Team
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -18,17 +18,6 @@ require "gobject-introspection"
 require "cairo-gobject"
 require "pango"
 
-base_dir = Pathname.new(__FILE__).dirname.dirname.expand_path
-vendor_dir = base_dir + "vendor" + "local"
-vendor_bin_dir = vendor_dir + "bin"
-GLib.prepend_dll_path(vendor_bin_dir)
-vendor_girepository_dir = vendor_dir + "lib" + "girepository-1.0"
-GObjectIntrospection.prepend_typelib_path(vendor_girepository_dir)
-
-if vendor_dir.exist?
-  require "gdk3"
-end
-
 module Clutter
   LOG_DOMAIN = "Clutter"
   GLib::Log.set_log_domain(LOG_DOMAIN)
