@@ -50,7 +50,7 @@ $topdir = File.expand_path($topdir)
 
 subdirs = ARGV.select{|v|  /^--/ !~ v}
 
-if subdirs.size == 0
+if subdirs.empty?
   subdirs = Dir.glob($topsrcdir+"/*/extconf.rb")
   subdirs.collect! do |subdir|
     subdir[0..$topsrcdir.size] = ""
