@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 #
-# Copyright (C) 2013-2016  Ruby-GNOME2 Project Team
+# Copyright (C) 2013-2020  Ruby-GNOME Project Team
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -16,12 +16,16 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-ruby_gnome2_base = File.join(File.dirname(__FILE__), "..", "..")
-ruby_gnome2_base = File.expand_path(ruby_gnome2_base)
+require "fileutils"
 
-glib_base = File.join(ruby_gnome2_base, "glib2")
-gobject_introspection_base = File.join(ruby_gnome2_base, "gobject-introspection")
-gio2_base = File.join(ruby_gnome2_base, "gio2")
+build_dir = File.expand_path(".")
+
+ruby_gnome_base = File.join(__dir__, "..", "..")
+ruby_gnome_base = File.expand_path(ruby_gnome_base)
+
+glib_base = File.join(ruby_gnome_base, "glib2")
+gobject_introspection_base = File.join(ruby_gnome_base, "gobject-introspection")
+gio2_base = File.join(ruby_gnome_base, "gio2")
 
 modules = [
   [glib_base, "glib2"],
@@ -38,11 +42,17 @@ modules.each do |target, module_name|
   $LOAD_PATH.unshift(File.join(target, "lib"))
 end
 
-fixture_dir = File.join(gio2_base, "test", "fixture")
-Dir.chdir(fixture_dir) do
+source_fixture_dir = File.join(gio2_base, "test", "fixture")
+build_fixture_dir = File.join(build_dir, "test", "fixture")
+unless source_fixture_dir == build_fixture_dir
+  FileUtils.rm_rf(build_fixture_dir)
+  FileUtils.mkdir_p(File.dirname(build_fixture_dir))
+  FileUtils.cp_r(source_fixture_dir, build_fixture_dir)
+end
+Dir.chdir(build_fixture_dir) do
   system("rake") or exit(false)
 end
-ENV["GSETTINGS_SCHEMA_DIR"] = File.join(fixture_dir, "schema", "default")
+ENV["GSETTINGS_SCHEMA_DIR"] = File.join(build_fixture_dir, "schema", "default")
 
 $LOAD_PATH.unshift(File.join(glib_base, "test"))
 require "glib-test-init"
