@@ -1,6 +1,6 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
 /*
- *  Copyright (C) 2004-2025  Ruby-GNOME Project Team
+ *  Copyright (C) 2004-2019  Ruby-GNOME Project Team
  *  Copyright (C) 2002,2003  Masahiro Sakai
  *
  *  This library is free software; you can redistribute it and/or
@@ -83,9 +83,7 @@ static const rb_data_type_t rg_glib_flags_type = {
     },
     NULL,
     NULL,
-    RUBY_TYPED_FREE_IMMEDIATELY |
-    RUBY_TYPED_WB_PROTECTED |
-    RUBY_TYPED_FROZEN_SHAREABLE,
+    RUBY_TYPED_FREE_IMMEDIATELY,
 };
 
 static flags_holder*
@@ -544,15 +542,10 @@ Init_gobject_gflags(void)
     id_or = rb_intern("|");
     id_to_i = rb_intern("to_i");
 
-    RG_TARGET_NAMESPACE = G_DEF_CLASS(G_TYPE_FLAGS, "Flags", rbg_mGLib());
+    RG_TARGET_NAMESPACE = G_DEF_CLASS(G_TYPE_FLAGS, "Flags", mGLib);
 
-    rb_define_singleton_method(RG_TARGET_NAMESPACE, "gtype", generic_s_gtype, 0);
-    rb_define_singleton_method(RG_TARGET_NAMESPACE,
-                               "to_s",
-                               rbgutil_generic_s_to_s_gtype_name_fallback,
-                               0);
-    RG_DEF_SALIAS("inspect", "to_s");
-    rb_define_method(RG_TARGET_NAMESPACE, "gtype", generic_gtype, 0);
+    rbg_define_singleton_method(RG_TARGET_NAMESPACE, "gtype", generic_s_gtype, 0);
+    rbg_define_method(RG_TARGET_NAMESPACE, "gtype", generic_gtype, 0);
 
     RG_DEF_SMETHOD(mask, 0);
     RG_DEF_SMETHOD(values, 0);
@@ -567,7 +560,7 @@ Init_gobject_gflags(void)
     RG_DEF_METHOD(nick, 0);
 
     /*
-    rb_define_method(RG_TARGET_NAMESPACE, "inspect", flags_inspect, 0);
+    rbg_define_method(RG_TARGET_NAMESPACE, "inspect", flags_inspect, 0);
     */
 
     RG_DEF_METHOD_OPERATOR("<=>", flags_compare, 1);
@@ -577,9 +570,9 @@ Init_gobject_gflags(void)
     RG_DEF_METHOD_OPERATOR(">", flags_gt, 1);
     RG_DEF_METHOD_OPERATOR("<", flags_lt, 1);
     RG_DEF_METHOD_OPERATOR("~", flags_not, 0);
-    rb_define_method(RG_TARGET_NAMESPACE, "&", flags_and, 1);
-    rb_define_method(RG_TARGET_NAMESPACE, "|", flags_or, 1);
-    rb_define_method(RG_TARGET_NAMESPACE, "^", flags_xor, 1);
+    rbg_define_method(RG_TARGET_NAMESPACE, "&", flags_and, 1);
+    rbg_define_method(RG_TARGET_NAMESPACE, "|", flags_or, 1);
+    rbg_define_method(RG_TARGET_NAMESPACE, "^", flags_xor, 1);
     RG_DEF_METHOD_OPERATOR("-", flags_minus, 1);
 
     RG_DEF_METHOD_P(empty, 0);
