@@ -1,6 +1,6 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
 /*
- *  Copyright (C) 2007-2024  Ruby-GNOME Project Team
+ *  Copyright (C) 2007-2019  Ruby-GNOME Project Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -21,17 +21,12 @@
 #pragma once
 
 /*
- * AlmaLinux 8: GLib 2.56
- * AlmaLinux 9: GLib 2.68
- * Ubuntu 20.04: GLib 2.64
- * Ubuntu 22.04: GLib 2.72
- * Ubuntu 24.04: GLib 2.80
+ * CentOS 6: GLib 2.28
+ * CentOS 7: GLib 2.50
+ * Ubuntu 16.04: GLib 2.48
+ * Ubuntu 18.04: GLib 2.54
  */
-#ifndef GLIB_VERSION_MIN_REQUIRED
-#  define GLIB_VERSION_MIN_REQUIRED GLIB_VERSION_2_56
-#endif
-
-#define G_LOG_DOMAIN "Ruby/GLib2"
+#define GLIB_VERSION_MIN_REQUIRED GLIB_VERSION_2_28
 
 #include "rbgobject.h"
 
@@ -47,10 +42,6 @@
 #  define G_VALUE_INIT { 0, { { 0 } } }
 #endif
 
-#ifndef RUBY_TYPED_FROZEN_SHAREABLE
-#  define RUBY_TYPED_FROZEN_SHAREABLE 0
-#endif
-
 G_BEGIN_DECLS
 
 typedef struct {
@@ -67,7 +58,7 @@ typedef struct {
     GType type;
 } boxed_holder;
 
-G_GNUC_INTERNAL extern GPrivate rg_polling_key;
+G_GNUC_INTERNAL extern GStaticPrivate rg_polling_key;
 G_GNUC_INTERNAL extern rb_encoding *rbg_filename_encoding;
 
 extern VALUE rbgobj_cEnum;
@@ -79,7 +70,6 @@ extern VALUE rbgobj_cObject;
 
 extern VALUE rbgobj_cInstantiatable;
 extern VALUE rbgobj_mMetaInterface;
-extern VALUE rbgobj_mMetaSignal;
 #define cInstantiatable   rbgobj_cInstantiatable
 #define mMetaInterface rbgobj_mMetaInterface
 
@@ -108,8 +98,6 @@ VALUE rbgutil_generic_gtype(VALUE self);
 #define generic_s_gtype rbgutil_generic_s_gtype
 #define generic_gtype rbgutil_generic_gtype
 
-VALUE rbgutil_generic_s_to_s_gtype_name_fallback(VALUE klass);
-
 extern gboolean rbgobj_convert_has_type(GType type);
 extern RGConvertTable *rbgobj_convert_lookup(GType type);
 
@@ -179,13 +167,11 @@ G_GNUC_INTERNAL void Init_glib_keyfile(void);
 G_GNUC_INTERNAL void Init_glib_bookmark_file(void);
 G_GNUC_INTERNAL void Init_glib_variant_type(void);
 G_GNUC_INTERNAL void Init_glib_variant(void);
-G_GNUC_INTERNAL void Init_glib_variant_dict(void);
 G_GNUC_INTERNAL void Init_glib_regex(void);
 G_GNUC_INTERNAL void Init_glib_matchinfo(void);
 G_GNUC_INTERNAL void Init_glib_date_time(void);
 G_GNUC_INTERNAL void Init_glib_time_zone(void);
 G_GNUC_INTERNAL void Init_glib_bytes(void);
-G_GNUC_INTERNAL void Init_glib_option(void);
 
 G_GNUC_INTERNAL void Init_gobject_convert(void);
 G_GNUC_INTERNAL void Init_gobject_gtype(void);
