@@ -120,7 +120,7 @@ rb_gi_ffi_closure_callback(G_GNUC_UNUSED ffi_cif *cif,
             i = args.metadata->len - 1;
             metadata = g_ptr_array_index(args.metadata, i);
             if (metadata->type.tag == GI_TYPE_TAG_VOID &&
-                metadata->pointer_p &&
+                metadata->type.pointer_p &&
                 strcmp(metadata->name, "data") == 0) {
                 callback_data = *((RBGICallbackData **)(raw_args[i]));
             }
@@ -721,26 +721,50 @@ rb_gi_arguments_in_init_arg_ruby_array_c_interface_struct(RBGIArguments *args,
 {
     GIStructInfo *struct_info =
         (GIStructInfo *)(metadata->element_type.interface_info);
-    guint8 *raw_array;
-    gsize struct_size;
     long i, n_elements;
 
     n_elements = RARRAY_LEN(rb_array);
-    struct_size = g_struct_info_get_size(struct_info);
-    raw_array = ALLOC_N(guint8, struct_size * n_elements);
-    for (i = 0; i < n_elements; i++) {
-        VALUE rb_element = RARRAY_AREF(rb_array, i);
-        gpointer element;
-        element = rb_gi_struct_info_from_ruby(struct_info, rb_element);
-        memcpy(raw_array + (struct_size * i),
-               element,
-               struct_size);
+    if (metadata->element_type.pointer_p) {
+        if (metadata->transfer != GI_TRANSFER_NOTHING) {
+            rb_raise(rb_eNotImpError,
+                     "TODO: [%s::%s] %s "
+                     "Ruby -> GIArgument(array/%s)[interface(%s)](%s)[%s]",
+                     args->name,
+                     metadata->name,
+                     rb_gi_direction_to_string(metadata->direction),
+                     rb_gi_array_type_to_string(metadata->array_type),
+                     g_info_type_to_string(metadata->element_type.interface_type),
+                     g_type_name(metadata->element_type.interface_gtype),
+                     rb_gi_transfer_to_string(metadata->transfer));
+        }
+        gpointer *raw_array = ALLOC_N(gpointer, n_elements);
+        for (i = 0; i < n_elements; i++) {
+            VALUE rb_element = RARRAY_AREF(rb_array, i);
+            gpointer element;
+            element = rb_gi_struct_info_from_ruby(struct_info, rb_element);
+            raw_array[i] = element;
+        }
+        rb_gi_arguments_in_init_arg_ruby_array_c_generic(args,
+                                                         metadata,
+                                                         rb_array,
+                                                         raw_array);
+    } else {
+        gsize struct_size = g_struct_info_get_size(struct_info);
+        guint8 *raw_array = ALLOC_N(guint8, struct_size * n_elements);
+        for (i = 0; i < n_elements; i++) {
+            VALUE rb_element = RARRAY_AREF(rb_array, i);
+            gpointer element;
+            element = rb_gi_struct_info_from_ruby(struct_info, rb_element);
+            memcpy(raw_array + (struct_size * i),
+                   element,
+                   struct_size);
+        }
+        rb_gi_arguments_in_init_arg_ruby_array_c_generic(args,
+                                                         metadata,
+                                                         rb_array,
+                                                         raw_array);
     }
 
-    rb_gi_arguments_in_init_arg_ruby_array_c_generic(args,
-                                                     metadata,
-                                                     rb_array,
-                                                     raw_array);
     metadata->free_func = rb_gi_arguments_in_free_array_c_interface_struct;
 }
 
@@ -980,7 +1004,15 @@ rb_gi_arguments_in_init_arg_ruby_array_c(RBGIArguments *args,
                                                        rb_arg);
         break;
       case GI_TYPE_TAG_UTF8:
-        {
+        /* Workaround for rsvg_handle_set_stylesheet():
+           https://gitlab.gnome.org/GNOME/librsvg/-/issues/596 */
+        if (strcmp(metadata->name, "css") == 0) {
+            metadata->in_arg->v_pointer = RVAL2CSTR(rb_arg);
+            rb_gi_arguments_in_init_arg_ruby_array_set_length(args,
+                                                              metadata,
+                                                              RSTRING_LEN(rb_arg));
+            metadata->free_func = NULL;
+        } else {
             GIArgument *array_argument = metadata->in_arg;
             gchar **raw_array;
             long length;
@@ -1645,7 +1677,15 @@ rb_gi_arguments_in_init_arg_ruby_ghash_body(VALUE value_data)
       case GI_TYPE_TAG_FLOAT:
       case GI_TYPE_TAG_DOUBLE:
       case GI_TYPE_TAG_GTYPE:
+        rb_raise(rb_eNotImpError,
+                 "TODO: Ruby -> GIArgument(GHash)[value][%s]",
+                 g_type_tag_to_string(metadata->value_type.tag));
+        break;
       case GI_TYPE_TAG_UTF8:
+        value_destroy_func = g_free;
+        value_ruby_to_c_func = ruby_to_c_utf8;
+        value_ruby_to_c_data.context = "Ruby -> GIArgument(GHash)[value][utf8]";
+        break;
       case GI_TYPE_TAG_FILENAME:
       case GI_TYPE_TAG_ARRAY:
         rb_raise(rb_eNotImpError,
