@@ -1,6 +1,6 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
 /*
- *  Copyright (C) 2012-2022  Ruby-GNOME Project Team
+ *  Copyright (C) 2012-2014  Ruby-GNOME2 Project Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -18,7 +18,8 @@
  *  MA  02110-1301  USA
  */
 
-#pragma once
+#ifndef RB_GI_CONVERSIONS_H
+#define RB_GI_CONVERSIONS_H
 
 #define RVAL2GI_REPOSITORY(rb_object) (G_IREPOSITORY(RVAL2GOBJ(rb_object)))
 #define RVAL2GI_REPOSITORY_LOAD_FLAGS(rb_flags) \
@@ -30,6 +31,16 @@
     (rb_gi_base_info_to_ruby_with_unref((GIBaseInfo *)(info)))
 #define RVAL2GI_BASE_INFO(rb_object) (rb_gi_base_info_from_ruby(rb_object))
 
+#define GI_ARGUMENT2RVAL(argument, duplicate, type_info,                \
+                         in_args, out_args, args_metadata)              \
+    (rb_gi_argument_to_ruby((argument), (duplicate), (type_info),       \
+                            (in_args), (out_args), (args_metadata)))
+#define GI_RETURN_ARGUMENT2RVAL(callable_info, argument,                \
+                                in_args, out_args, args_metadata)       \
+    (rb_gi_return_argument_to_ruby((callable_info), (argument),         \
+                                   (in_args), (out_args), (args_metadata)))
+
+
 #define RVAL2GI_REGISTERED_TYPE_INFO(rb_object)			\
     ((GIRegisteredTypeInfo *)RVAL2GI_BASE_INFO(rb_object))
 #define RVAL2GI_FUNCTION_INFO(rb_object)			\
@@ -54,10 +65,6 @@
     ((GIFieldInfo *)RVAL2GI_BASE_INFO(rb_object))
 #define RVAL2GI_TYPE_INFO(rb_object)			\
     ((GITypeInfo *)RVAL2GI_BASE_INFO(rb_object))
-#define RVAL2GI_CALLABLE_INFO(rb_object)                \
-    ((GICallableInfo *)RVAL2GI_BASE_INFO(rb_object))
-#define RVAL2GI_VFUNC_INFO(rb_object)			\
-    ((GIVFuncInfo *)RVAL2GI_BASE_INFO(rb_object))
 
 #define GI_INFO_TYPE2RVAL(type)      (GENUM2RVAL(type, G_TYPE_I_INFO_TYPE))
 #define GI_TRANSFER2RVAL(transfer)   (GENUM2RVAL(transfer, G_TYPE_I_TRANSFER))
@@ -80,4 +87,19 @@ VALUE       rb_gi_base_info_to_ruby           (GIBaseInfo *info);
 VALUE       rb_gi_base_info_to_ruby_with_unref(GIBaseInfo *info);
 GIBaseInfo *rb_gi_base_info_from_ruby         (VALUE rb_info);
 
+VALUE       rb_gi_argument_to_ruby            (GIArgument     *argument,
+                                               gboolean        duplicate,
+                                               GITypeInfo     *type_info,
+                                               GArray         *in_args,
+                                               GArray         *out_args,
+                                               GPtrArray      *args_metadata);
+VALUE       rb_gi_return_argument_to_ruby     (GICallableInfo *callable_info,
+                                               GIArgument     *argument,
+                                               GArray         *in_args,
+                                               GArray         *out_args,
+                                               GPtrArray      *args_metadata);
+
 VALUE       rb_gi_array_type_to_ruby          (GIArrayType type);
+
+#endif
+
