@@ -1,4 +1,4 @@
-# Copyright (C) 2015  Ruby-GNOME2 Project Team
+# Copyright (C) 2015-2019  Ruby-GNOME Project Team
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -22,6 +22,25 @@ module GObjectIntrospection
       @gclosure_p = compute_gclosure?
     end
 
+    def signature
+      sig = "#{name}:"
+      sig << " (optional)" if optional?
+      sig << " (may be null)" if may_be_null?
+      sig << " (caller allocates)" if caller_allocates?
+      sig << " #{type.description}"
+      sig
+    end
+
+    def inspect
+      super.gsub(/>\z/) do
+        " name=#{name.inspect}" +
+          " optional?=#{optional?.inspect}" +
+          " may_be_null?=#{may_be_null?.inspect}" +
+          " caller_allocates?=#{caller_allocates?.inspect}" +
+          " type=#{type.inspect}>"
+      end
+    end
+
     private
     def compute_gclosure?
       type_info = type
