@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 #
-# Copyright (C) 2013-2017  Ruby-GNOME2 Project Team
+# Copyright (C) 2013-2020  Ruby-GNOME Project Team
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -16,18 +16,22 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-ruby_gnome2_base = File.join(File.dirname(__FILE__), "..", "..")
-ruby_gnome2_base = File.expand_path(ruby_gnome2_base)
+require "fileutils"
 
-glib_base = File.join(ruby_gnome2_base, "glib2")
-gobject_introspection_base = File.join(ruby_gnome2_base, "gobject-introspection")
-atk_base = File.join(ruby_gnome2_base, "atk")
-cairo_gobject_base = File.join(ruby_gnome2_base, "cairo-gobject")
-pango_base = File.join(ruby_gnome2_base, "pango")
-gdk_pixbuf_base = File.join(ruby_gnome2_base, "gdk_pixbuf2")
-gio2_base = File.join(ruby_gnome2_base, "gio2")
-gdk3_base = File.join(ruby_gnome2_base, "gdk3")
-gtk3_base = File.join(ruby_gnome2_base, "gtk3")
+build_dir = File.expand_path(".")
+
+ruby_gnome_base = File.join(__dir__, "..", "..")
+ruby_gnome_base = File.expand_path(ruby_gnome_base)
+
+glib_base = File.join(ruby_gnome_base, "glib2")
+gobject_introspection_base = File.join(ruby_gnome_base, "gobject-introspection")
+atk_base = File.join(ruby_gnome_base, "atk")
+cairo_gobject_base = File.join(ruby_gnome_base, "cairo-gobject")
+pango_base = File.join(ruby_gnome_base, "pango")
+gdk_pixbuf_base = File.join(ruby_gnome_base, "gdk_pixbuf2")
+gio2_base = File.join(ruby_gnome_base, "gio2")
+gdk3_base = File.join(ruby_gnome_base, "gdk3")
+gtk3_base = File.join(ruby_gnome_base, "gtk3")
 
 [
   [glib_base, "glib2"],
@@ -49,7 +53,14 @@ gtk3_base = File.join(ruby_gnome2_base, "gtk3")
   $LOAD_PATH.unshift(File.join(target, "lib"))
 end
 
-Dir.chdir(File.join(gtk3_base, "test", "fixture")) do
+source_fixture_dir = File.join(gtk3_base, "test", "fixture")
+build_fixture_dir = File.join(build_dir, "test", "fixture")
+unless source_fixture_dir == build_fixture_dir
+  FileUtils.rm_rf(build_fixture_dir)
+  FileUtils.mkdir_p(File.dirname(build_fixture_dir))
+  FileUtils.cp_r(source_fixture_dir, build_fixture_dir)
+end
+Dir.chdir(build_fixture_dir) do
   system("rake") or exit(false)
 end
 
