@@ -42,27 +42,27 @@ class TestDocument < Test::Unit::TestCase
   end
 
   def test_save
-    saved_pdf = File.join(tmp_dir, "saved.pdf")
-    FileUtils.rm_f(saved_pdf)
-
-    document = Poppler::Document.new(text_field_pdf)
-    find_first_text_field(document).text = "XXX"
-    document.save(saved_pdf)
-    reread_document = Poppler::Document.new(saved_pdf)
-    assert_equal("XXX", find_first_text_field(reread_document).text)
+    Dir.mktmpdir do |tmp_dir|
+      saved_pdf = File.join(tmp_dir, "saved.pdf")
+      document = Poppler::Document.new(text_field_pdf)
+      find_first_text_field(document).text = "XXX"
+      document.save(saved_pdf)
+      reread_document = Poppler::Document.new(saved_pdf)
+      assert_equal("XXX", find_first_text_field(reread_document).text)
+    end
   end
 
   def test_save_a_copy
-    copied_pdf = File.join(tmp_dir, "copied.pdf")
-    FileUtils.rm_f(copied_pdf)
-
-    document = Poppler::Document.new(text_field_pdf)
-    first_text_field = find_first_text_field(document)
-    default_text = first_text_field.text
-    first_text_field.text = "XXX"
-    document.save_a_copy(copied_pdf)
-    reread_document = Poppler::Document.new(copied_pdf)
-    assert_equal(default_text, find_first_text_field(reread_document).text)
+    Dir.mktmpdir do |tmp_dir|
+      copied_pdf = File.join(tmp_dir, "copied.pdf")
+      document = Poppler::Document.new(text_field_pdf)
+      first_text_field = find_first_text_field(document)
+      default_text = first_text_field.text
+      first_text_field.text = "XXX"
+      document.save_a_copy(copied_pdf)
+      reread_document = Poppler::Document.new(copied_pdf)
+      assert_equal(default_text, find_first_text_field(reread_document).text)
+    end
   end
 
   def test_each
