@@ -1,4 +1,4 @@
-# Copyright (C) 2015  Ruby-GNOME2 Project Team
+# Copyright (C) 2015-2017  Ruby-GNOME2 Project Team
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -22,6 +22,8 @@ vendor_dir = base_dir + "vendor" + "local"
 vendor_bin_dir = vendor_dir + "bin"
 GLib.prepend_dll_path(vendor_bin_dir)
 
+require "webkit2-gtk/loader"
+
 module WebKit2Gtk
   class << self
     def const_missing(name)
@@ -43,39 +45,4 @@ module WebKit2Gtk
       loader.load
     end
   end
-
-  class Loader < GObjectIntrospection::Loader
-    NAMESPACE = "WebKit2"
-
-    def load
-      super(NAMESPACE)
-    end
-
-    private
-    def pre_load(repository, namespace)
-      define_version_module
-    end
-
-    def post_load(repository, namespace)
-      require_libraries
-    end
-
-    def define_version_module
-      @version_module = Module.new
-      @base_module.const_set("Version", @version_module)
-    end
-
-    def require_libraries
-      require "webkit2-gtk/version" if @version_module.const_defined?(:MAJOR)
-    end
-
-    def load_constant_info(info)
-      case info.name
-      when /_VERSION\z/
-        @version_module.const_set($PREMATCH, info.value)
-      else
-        super
-      end
-    end
-  end
 end
